coap
====

[![Health](https://landscape.io/github/openwsn-berkeley/coap/develop/landscape.png)](https://landscape.io/github/openwsn-berkeley/coap/develop)
[![Travis](https://travis-ci.org/openwsn-berkeley/coap.png?branch=develop)](https://travis-ci.org/openwsn-berkeley/coap)
[![Builder](http://builder.openwsn.org/buildStatus/icon?job=CoAP Unit Tests)](http://builder.openwsn.org/job/CoAP%20Unit%20Tests/)

A CoAP Python library

This package implements the Constrained Application Protocol (CoAP)
developed by the IETF CORE working group.

This package aims at implementing:
http://tools.ietf.org/html/draft-ietf-core-coap-18

In particular, it implements:
- a CoAP client
- a CoAP server with an arbitrary number of resources

Full documentation at https://openwsn.atlassian.net/wiki/display/OW/CoAP+Python+Library.

Report bugs at https://openwsn.atlassian.net/browse/COAP.

This package is part of Berkeley's OpenWSN project,
http://www.openwsn.org/.
